==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QAnimationDriver_shell.h <==
#ifndef QANIMATIONDRIVER_SHELL_H
#define QANIMATIONDRIVER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtcore-config.h>
#if QT_CONFIG(animation)
#include <QtCore/qabstractanimation.h>
#endif //QT_CONFIG(animation)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(animation)

class QAnimationDriver_shell : public QAnimationDriver, public QtJambiShellInterface
{
public:
    QAnimationDriver_shell(QObject* parent0 = nullptr);
    ~QAnimationDriver_shell() override;

    void advance() override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    qint64 elapsed() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void start() override;
    void stop() override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAnimationDriver_access : public QAnimationDriver
{
    void __qt_advanceAnimation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_advance(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jlong __qt_elapsed(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_start(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_stop(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QT_CONFIG(animation)
#endif // QANIMATIONDRIVER_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QAnimationDriver_shell.h <==
#ifndef QANIMATIONDRIVER_SHELL_H
#define QANIMATIONDRIVER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtcore-config.h>
#if QT_CONFIG(animation)
#include <QtCore/qabstractanimation.h>
#endif //QT_CONFIG(animation)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(animation)

class QAnimationDriver_shell : public QAnimationDriver, public QtJambiShellInterface
{
public:
    QAnimationDriver_shell(QObject* parent0 = nullptr);
    ~QAnimationDriver_shell() override;

    void advance() override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    qint64 elapsed() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void start() override;
    void stop() override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAnimationDriver_access : public QAnimationDriver
{
    void __qt_advanceAnimation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_advance(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jlong __qt_elapsed_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_start(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_stop(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QT_CONFIG(animation)
#endif // QANIMATIONDRIVER_SHELL_H
